import numpy as np


def get_model_9_params():
    """
    Returns all the parameters related to model 9 (GangFeng 100Ah LFP).
    """
    return {
        "Q": np.float32(0.1),  # State transition matrix 1x1
        "H": np.float32(1),  # Observation matrix 1x1
        "R": np.float32(8.51290239e12),  # Process noise covariance 1x1
        "x3": np.array(
            [
                0.0,
                0.03,
                0.05,
                0.1,
                0.15,
                0.2,
                0.25,
                0.3,
                0.35,
                0.4,
                0.45,
                0.5,
                0.55,
                0.6,
                0.65,
                0.7,
                0.75,
                0.8,
                0.85,
                0.9,
                0.95,
                0.98,
                1.0,
            ]
        ),
        "y3": np.array(
            [
                2.9076,
                3.1493,
                3.20125,
                3.21665,
                3.2408,
                3.26405,
                3.28,
                3.29235,
                3.297,
                3.29795,
                3.29905,
                3.3002,
                3.3019,
                3.3051,
                3.33085,
                3.3362,
                3.3364,
                3.33665,
                3.33665,
                3.33625,
                3.33575,
                3.33505,
                3.4006,
            ]
        ),
        "capacity": np.float32(100),
        "num_cells_parallel": np.float32(1),
        "num_cells_series": np.float32(16),
    }


def get_model_3_params():
    """
    Returns all the parameters related to model 9 (GangFeng 100Ah LFP).
    """
    return {
        "Q": np.float32(0.1),  # State transition matrix 1x1
        "H": np.float32(1),  # Observation matrix 1x1
        "R": np.float32(1.0),  # Process noise covariance 1x1
        "x3": np.array(
            [
                0.0,
                0.01,
                0.02,
                0.03,
                0.04,
                0.05,
                0.06,
                0.07,
                0.08,
                0.09,
                0.1,
                0.11,
                0.12,
                0.13,
                0.14,
                0.15,
                0.16,
                0.17,
                0.18,
                0.19,
                0.2,
                0.21,
                0.22,
                0.23,
                0.24,
                0.25,
                0.26,
                0.27,
                0.28,
                0.29,
                0.3,
                0.31,
                0.32,
                0.33,
                0.34,
                0.35,
                0.36,
                0.37,
                0.38,
                0.39,
                0.4,
                0.41,
                0.42,
                0.43,
                0.44,
                0.45,
                0.46,
                0.47,
                0.48,
                0.49,
                0.5,
                0.51,
                0.52,
                0.53,
                0.54,
                0.55,
                0.56,
                0.57,
                0.58,
                0.59,
                0.6,
                0.61,
                0.62,
                0.63,
                0.64,
                0.65,
                0.66,
                0.67,
                0.68,
                0.69,
                0.7,
                0.71,
                0.72,
                0.73,
                0.74,
                0.75,
                0.76,
                0.77,
                0.78,
                0.79,
                0.8,
                0.81,
                0.82,
                0.83,
                0.84,
                0.85,
                0.86,
                0.87,
                0.88,
                0.89,
                0.9,
                0.91,
                0.92,
                0.93,
                0.94,
                0.95,
                0.96,
                0.97,
                0.98,
                0.99,
                1.0,
                1.01,
                1.02,
                1.03,
            ]
        ),
        "y3": np.array(
            [
                2.411191667,
                2.86975,
                2.987491667,
                3.062583333,
                3.117908333,
                3.160816667,
                3.190866667,
                3.201225,
                3.204808333,
                3.207225,
                3.2094,
                3.211733333,
                3.214658333,
                3.218816667,
                3.225641667,
                3.2334,
                3.238483333,
                3.243983333,
                3.2494,
                3.254533333,
                3.258916667,
                3.26295,
                3.266816667,
                3.270466667,
                3.273683333,
                3.276333333,
                3.279066667,
                3.282,
                3.284816667,
                3.2871,
                3.289016667,
                3.290766667,
                3.29225,
                3.29345,
                3.2944,
                3.2951,
                3.29575,
                3.29645,
                3.29705,
                3.297666667,
                3.298166667,
                3.298666667,
                3.299116667,
                3.299516667,
                3.299866667,
                3.3002,
                3.3006,
                3.30095,
                3.301366667,
                3.301783333,
                3.302216667,
                3.302683333,
                3.30315,
                3.303683333,
                3.304333333,
                3.305066667,
                3.305983333,
                3.307116667,
                3.308583333,
                3.3105,
                3.3132,
                3.316883333,
                3.321666667,
                3.327383333,
                3.329333333,
                3.331483333,
                3.33295,
                3.334083333,
                3.335016667,
                3.335633333,
                3.336166667,
                3.33665,
                3.337166667,
                3.337616667,
                3.337983333,
                3.338333333,
                3.33865,
                3.3389,
                3.339216667,
                3.3395,
                3.3398,
                3.340016667,
                3.340383333,
                3.340716667,
                3.341116667,
                3.341433333,
                3.3417,
                3.342016667,
                3.342266667,
                3.342583333,
                3.342833333,
                3.3432,
                3.3436,
                3.344083333,
                3.3447,
                3.345433333,
                3.346316667,
                3.347283333,
                3.34855,
                3.350283333,
                3.353083333,
                3.35905,
                3.406933333,
                3.600033333,
            ]
        ),
        "capacity": np.float32(15),
        "num_cells_parallel": np.float32(3),
        "num_cells_series": np.float32(16),
    }
